import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useState, useEffect, useRef } from 'react';
import { Button, Card, CardBody, CardHeader, Heading, Stack, Text } from '@chakra-ui/react';
import { VoiceRecorder as CapacitorVoiceRecorder } from 'capacitor-voice-recorder';
import { useRecordingStatus } from '../hooks/use-recording-status';
import { useRecordingCycle } from '../hooks/use-recording-cycle';
import { useContainer } from '../hooks/use-container';
import { startRecording } from '../strart-recording';
import { stopRecording } from '../stop-recording';
import { downloadRecords } from '../download-records';
// React component for voice-recorder
export function VoiceRecorder({ deep }) {
    const [recording, setRecording] = useState(false); // State variable to track recording status
    const [records, setRecords] = useState([]); // State variable to store downloaded audio files
    const [arePermissionsGranted, setArePermissionsGranted] = useState(undefined); // State variable to track audio recording permissions
    const [canDeviceRecord, setCanDeviceRecord] = useState(undefined); // State variable to check if device can record
    useEffect(() => {
        new Promise(async () => {
            const { value: canDeviceRecord } = await CapacitorVoiceRecorder.canDeviceVoiceRecord(); // Check if device can record audio
            setCanDeviceRecord(canDeviceRecord);
        });
    }, []);
    const containerLinkId = useContainer(deep); // Custom hook to get container link ID
    const audioRecordingStatus = useRecordingStatus({}); // Custom hook to get audio recording status
    const sounds = useRecordingCycle({ deep, recording, containerLinkId, duration: 5000 }); // Custom hook to fire recording cycle
    const startTime = useRef(''); // Reference to store start time of recording
    return (_jsxs(Stack, { children: [_jsxs(Card, { children: [_jsx(CardHeader, { children: _jsx(Heading, { children: "Ability to record" }) }), _jsx(CardBody, { children: _jsx(Text, { children: `Device is ${!canDeviceRecord ? 'not' : ''} able to record.` }) })] }), _jsxs(Card, { children: [_jsx(CardHeader, { children: _jsx(Heading, { children: "Permissions" }) }), _jsxs(CardBody, { children: [_jsx(Text, { children: `Permissions are ${!arePermissionsGranted ? 'not' : ''} granted.` }), _jsx(Button, { onClick: async () => {
                                    const { value: arePermissionsGranted } = await CapacitorVoiceRecorder.requestAudioRecordingPermission(); // Request audio recording permission
                                    setArePermissionsGranted(arePermissionsGranted);
                                }, children: "Request permissions" })] })] }), _jsx(Card, { children: _jsx(CardHeader, { children: _jsx(Heading, { children: `Audio Recording Status: ${audioRecordingStatus}` }) }) }), _jsx(Card, { children: _jsx(CardHeader, { children: _jsx(Heading, { children: `Container Link Id: ${containerLinkId}` }) }) }), _jsx(Button, { onClick: async () => startTime.current = await startRecording(), children: "START RECORDING" }), _jsx(Button, { onClick: async () => await stopRecording({ deep, containerLinkId, startTime: startTime.current }), children: "STOP RECORDING" }), _jsx(Button, { onClick: () => setRecording(true), children: "START RECORDING CYCLE" }), _jsx(Button, { onClick: () => setRecording(false), children: "STOP RECORDING CYCLE" }), _jsx(Button, { onClick: async () => setRecords(await downloadRecords(deep)), children: "DOWNLOAD RECORDS" }), records?.map((r) => (_jsx("audio", { controls: true, src: `data:${r.mimetype};base64,${r.sound}` }, Math.random().toString())))] }));
}
